@@ -2,7 +2,7 @@
 /**
  * Turba directory driver implementation for virtual address books.
  *
- * Copyright 2005-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2005-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -29,9 +29,21 @@ class Turba_Driver_Vbook extends Turba_Driver
     public $searchCriteria;
 
     /**
+     * The composed driver.
      *
-     * @see Turba_Driver::__construct
-     * @throws Turba_Exception
+     * @var Turba_Driver
+     */
+    protected $_driver;
+
+    /**
+     * Constructs a new Turba_Driver object.
+     *
+     * @param string $name   Source name
+     * @param array $params  Additional configuration parameters:
+     *        - share: Horde_Share object representing this vbook.
+     *        - source: The configuration array of the parent source or the
+     *                  source name of parent source in the global cfgSources
+     *                  array.
      */
     public function __construct($name = '', array $params = array())
     {
@@ -41,7 +53,9 @@ class Turba_Driver_Vbook extends Turba_Driver
         $this->_share = $this->_params['share'];
 
         /* Load the underlying driver. */
-        $this->_driver = $GLOBALS['injector']->getInstance('Turba_Factory_Driver')->create($this->_params['source']);
+        $this->_driver = $GLOBALS['injector']
+            ->getInstance('Turba_Factory_Driver')
+            ->create($this->_params['source']);
 
         $this->searchCriteria = empty($this->_params['criteria'])
             ? array()
@@ -51,6 +65,24 @@ class Turba_Driver_Vbook extends Turba_Driver
             : 'basic';
     }
 
+    /**
+     * Remove all data for a specific user.
+     *
+     * @param string $user  The user to remove all data for.
+     */
+    public function removeUserData($user)
+    {
+        // Make sure we are being called by an admin.
+        if (!$GLOBALS['registry']->isAdmin()) {
+            throw new Horde_Exception_PermissionDenied(_("Permission denied"));
+        }
+
+        $GLOBALS['injector']
+            ->getInstance('Turba_Shares')
+            ->removeShare($this->_share);
+        unset($this->_share);
+    }
+
     /**
      * Return the owner to use when searching or creating contacts in
      * this address book.
